==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/src/advance/lang.cpp <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#include <WScom.h>
#include <WSClocaleSet.h>
#include <WSCinitializeManager.h>

void _libwsad_lang_init_proc(){
#include "English.cpp"
#include "Japanese.cpp"
#include "Japanese-sjis.cpp"
#include "Japanese-utf8.cpp"
}

class _libwsad_lang_init_{
public:
  _libwsad_lang_init_(){
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc);
  };
};

static _libwsad_lang_init_ _run_libwsad_lang_init;

==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/src/advance/lang.cpp <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#include <WScom.h>
#include <WSClocaleSet.h>
#include <WSCinitializeManager.h>

void _libwsad_lang_init_proc(){
#include "English.cpp"
}
void _libwsad_lang_init_proc1(){
#include "Japanese.cpp"
}
void _libwsad_lang_init_proc2(){
#include "Japanese-sjis.cpp"
}
void _libwsad_lang_init_proc3(){
#include "Japanese-utf8.cpp"
}
void _libwsad_lang_init_proc4(){
#include "Korean.cpp"
}
void _libwsad_lang_init_proc5(){
#include "Chinese-zh_cn.cpp"
}

class _libwsad_lang_init_{
public:
  _libwsad_lang_init_(){
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc);
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc1);
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc2);
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc3);
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc4);
    WSGIappInitializeManager()->addInitializeProc(_libwsad_lang_init_proc5);
  };
};

static _libwsad_lang_init_ _run_libwsad_lang_init;
